@@ -1,7 +1,7 @@
 /*
  * DSI utilities
  *
- * Copyright (C) 2007-2021 Sebastiano Vigna
+ * Copyright (C) 2007-2022 Sebastiano Vigna
  *
  * This program and the accompanying materials are made available under the
  * terms of the GNU Lesser General Public License v2.1 or later,
@@ -189,6 +189,15 @@ public class LongBigArrayBitVector extends AbstractBitVector implements Cloneabl
 		return length;
 	}
 
+	/**
+	 * Returns the underlying big array.
+	 *
+	 * @return the underlying big array.
+	 */
+	public long[][] bigBits() {
+		return bits;
+	}
+
 	/**
 	 * Ensures that this bit vector can hold the specified number of bits.
 	 *
